==> peony-extensions_4.10.0.0.orig.tar.gz: peony-extensions-4.10.0.0/peony-drive-rename/translations/peony-drive-rename_mn.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="mn">
<context>
    <name>Peony::DriveRename</name>
    <message>
        <source>drive rename</source>
        <translation type="vanished">设备重命名</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="166"/>
        <location filename="../drive-rename.cpp" line="178"/>
        <source>Rename</source>
        <translation>ᠳᠠᠬᠢᠨ ᠨᠡᠷᠡᠢᠳᠬᠦ</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="178"/>
        <source>Device name:</source>
        <translation>ᠳᠦᠬᠦᠬᠡᠷᠦᠮᠵᠢ ᠵᠢᠨ ᠨᠡᠷᠡᠢᠳᠦᠯ:</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="182"/>
        <location filename="../drive-rename.cpp" line="190"/>
        <location filename="../drive-rename.cpp" line="196"/>
        <source>Warning</source>
        <translation>ᠰᠡᠷᠡᠮᠵᠢᠯᠡᠬᠦᠯᠦᠯ</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="182"/>
        <source>Renaming cannot start with a decimal point, Please re-enter!</source>
        <translation>ᠳᠠᠬᠢᠨ ᠨᠡᠷᠡᠢᠳᠦᠯ ᠪᠤᠳᠠᠷᠬᠠᠢ ᠲᠤᠭ᠎ᠠ ᠪᠡᠷ ᠡᠬᠢᠯᠡᠵᠤ ᠪᠤᠯᠬᠤ ᠦᠬᠡᠢ᠂ ᠳᠠᠬᠢᠵᠤ ᠤᠷᠤᠭᠤᠯᠤᠭᠠᠷᠠᠢ!</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="190"/>
        <source>The device name exceeds the character limit, rename failed!</source>
        <translation>ᠲᠦᠬᠦᠬᠡᠷᠡᠮᠵᠢ ᠵᠢᠨ ᠨᠡᠷᠡᠢᠳᠦᠯ ᠦᠰᠦᠭ ᠤ᠋ᠨ ᠲᠤᠭᠠᠨ ᠤᠤ ᠬᠢᠵᠠᠭᠠᠷᠯᠠᠯ ᠡᠴᠡ ᠬᠡᠳᠦᠷᠡᠭᠰᠡᠨ᠂ ᠳᠠᠬᠢᠨ ᠨᠡᠷᠡᠢᠳᠴᠤ ᠴᠢᠳᠠᠭᠰᠠᠨ ᠦᠬᠡᠢ!</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="196"/>
        <source>Renaming will unmount the device. Do you want to continue?</source>
        <translation>ᠳᠠᠬᠢᠨ ᠨᠡᠷᠡᠢᠳᠬᠦ ᠳ᠋ᠤ᠌ ᠬᠦᠷᠪᠡᠯ ᠳᠦᠬᠦᠬᠡᠷᠦᠮᠵᠢ ᠵᠢ ᠪᠠᠭᠤᠯᠭᠠᠵᠤ ᠮᠡᠳᠡᠨ᠎ᠡ᠂ ᠦᠷᠬᠦᠯᠵᠢᠯᠡᠨ ᠬᠦᠢᠴᠡᠳᠬᠡᠬᠦ ᠤᠤ?</translation>
    </message>
    <message>
        <source>The device may not support the rename operation, rename failed!</source>
        <translation type="vanished">ᠳᠦᠬᠦᠬᠡᠷᠦᠮᠵᠢ ᠳᠠᠬᠢᠨ ᠨᠡᠷᠡᠢᠳᠬᠦ ᠵᠢ ᠳᠡᠮᠵᠢᠬᠦ ᠦᠬᠡᠢ ᠪᠠᠢᠵᠤ ᠮᠡᠳᠡᠨ᠎ᠡ᠂ ᠳᠠᠬᠢᠨ ᠨᠡᠷᠡᠢᠳᠴᠤ ᠴᠢᠳᠠᠭᠰᠠᠨ ᠦᠬᠡᠢ!</translation>
    </message>
    <message>
        <source>Failed to rename!</source>
        <translation type="vanished">重命名失败！</translation>
    </message>
</context>
<context>
    <name>Peony::DriveRenamePlugin</name>
    <message>
        <location filename="../driverenameplugin.h" line="21"/>
        <source>drive rename</source>
        <translation>ᠳᠦᠬᠦᠬᠡᠷᠦᠮᠵᠢ ᠵᠢᠨ ᠳᠠᠬᠢᠨ ᠨᠡᠷᠡᠢᠳᠦᠯ</translation>
    </message>
</context>
<context>
    <name>Peony::DriverAction</name>
    <message>
        <source>Send to a removable device</source>
        <translation type="vanished">发送到移动设备</translation>
    </message>
</context>
<context>
    <name>Peony::SendToPlugin</name>
    <message>
        <source>Send to a removable device</source>
        <translation type="vanished">发送到移动设备</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../drive-rename.cpp" line="328"/>
        <source>Warning</source>
        <translation>ᠰᠡᠷᠡᠮᠵᠢ ᠥᠭ᠍ᠬᠦ</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="328"/>
        <source>The device may not support the rename operation, rename failed!</source>
        <translation>ᠲᠥᠬᠥᠭᠡᠷᠦᠮᠵᠢ ᠬᠦᠨᠳᠦ ᠨᠡᠷᠡᠶᠢᠳᠦᠨ ᠠᠵᠢᠯᠯᠠᠬᠤ ᠶᠢ ᠳᠡᠮᠵᠢᠬᠦ ᠦᠭᠡᠢ ᠮᠠᠭᠠᠳ ᠂ ᠬᠦᠨᠳᠦ ᠪᠡᠷ ᠨᠡᠷᠡᠶᠢᠳᠦᠯ ᠢᠯᠠᠭᠳᠠᠵᠠᠢ !</translation>
    </message>
</context>
</TS>

==> peony-extensions_4.20.0.0.orig.tar.gz: peony-extensions-4.20.0.0/peony-drive-rename/translations/peony-drive-rename_mn.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="mn">
<context>
    <name>Peony::DriveRename</name>
    <message>
        <source>drive rename</source>
        <translation type="vanished">设备重命名</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="181"/>
        <location filename="../drive-rename.cpp" line="193"/>
        <source>Rename</source>
        <translation>ᠳᠠᠬᠢᠨ ᠨᠡᠷᠡᠢᠳᠬᠦ</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="193"/>
        <source>Device name:</source>
        <translation>ᠳᠦᠬᠦᠬᠡᠷᠦᠮᠵᠢ ᠵᠢᠨ ᠨᠡᠷᠡᠢᠳᠦᠯ:</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="197"/>
        <location filename="../drive-rename.cpp" line="205"/>
        <location filename="../drive-rename.cpp" line="211"/>
        <source>Warning</source>
        <translation>ᠰᠡᠷᠡᠮᠵᠢᠯᠡᠬᠦᠯᠦᠯ</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="197"/>
        <source>Renaming cannot start with a decimal point, Please re-enter!</source>
        <translation>ᠳᠠᠬᠢᠨ ᠨᠡᠷᠡᠢᠳᠦᠯ ᠪᠤᠳᠠᠷᠬᠠᠢ ᠲᠤᠭ᠎ᠠ ᠪᠡᠷ ᠡᠬᠢᠯᠡᠵᠤ ᠪᠤᠯᠬᠤ ᠦᠬᠡᠢ᠂ ᠳᠠᠬᠢᠵᠤ ᠤᠷᠤᠭᠤᠯᠤᠭᠠᠷᠠᠢ!</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="205"/>
        <source>The device name exceeds the character limit, rename failed!</source>
        <translation>ᠲᠦᠬᠦᠬᠡᠷᠡᠮᠵᠢ ᠵᠢᠨ ᠨᠡᠷᠡᠢᠳᠦᠯ ᠦᠰᠦᠭ ᠤ᠋ᠨ ᠲᠤᠭᠠᠨ ᠤᠤ ᠬᠢᠵᠠᠭᠠᠷᠯᠠᠯ ᠡᠴᠡ ᠬᠡᠳᠦᠷᠡᠭᠰᠡᠨ᠂ ᠳᠠᠬᠢᠨ ᠨᠡᠷᠡᠢᠳᠴᠤ ᠴᠢᠳᠠᠭᠰᠠᠨ ᠦᠬᠡᠢ!</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="211"/>
        <source>Renaming will unmount the device. Do you want to continue?</source>
        <translation>ᠳᠠᠬᠢᠨ ᠨᠡᠷᠡᠢᠳᠬᠦ ᠳ᠋ᠤ᠌ ᠬᠦᠷᠪᠡᠯ ᠳᠦᠬᠦᠬᠡᠷᠦᠮᠵᠢ ᠵᠢ ᠪᠠᠭᠤᠯᠭᠠᠵᠤ ᠮᠡᠳᠡᠨ᠎ᠡ᠂ ᠦᠷᠬᠦᠯᠵᠢᠯᠡᠨ ᠬᠦᠢᠴᠡᠳᠬᠡᠬᠦ ᠤᠤ?</translation>
    </message>
    <message>
        <source>The device may not support the rename operation, rename failed!</source>
        <translation type="vanished">ᠳᠦᠬᠦᠬᠡᠷᠦᠮᠵᠢ ᠳᠠᠬᠢᠨ ᠨᠡᠷᠡᠢᠳᠬᠦ ᠵᠢ ᠳᠡᠮᠵᠢᠬᠦ ᠦᠬᠡᠢ ᠪᠠᠢᠵᠤ ᠮᠡᠳᠡᠨ᠎ᠡ᠂ ᠳᠠᠬᠢᠨ ᠨᠡᠷᠡᠢᠳᠴᠤ ᠴᠢᠳᠠᠭᠰᠠᠨ ᠦᠬᠡᠢ!</translation>
    </message>
    <message>
        <source>Failed to rename!</source>
        <translation type="vanished">重命名失败！</translation>
    </message>
</context>
<context>
    <name>Peony::DriveRenamePlugin</name>
    <message>
        <source>drive rename</source>
        <translation type="vanished">ᠳᠦᠬᠦᠬᠡᠷᠦᠮᠵᠢ ᠵᠢᠨ ᠳᠠᠬᠢᠨ ᠨᠡᠷᠡᠢᠳᠦᠯ</translation>
    </message>
    <message>
        <location filename="../driverenameplugin.h" line="41"/>
        <source>Drive rename</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Peony::DriverAction</name>
    <message>
        <source>Send to a removable device</source>
        <translation type="vanished">发送到移动设备</translation>
    </message>
</context>
<context>
    <name>Peony::SendToPlugin</name>
    <message>
        <source>Send to a removable device</source>
        <translation type="vanished">发送到移动设备</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../drive-rename.cpp" line="343"/>
        <source>Warning</source>
        <translation>ᠰᠡᠷᠡᠮᠵᠢ ᠥᠭ᠍ᠬᠦ</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="343"/>
        <source>The device may not support the rename operation, rename failed!</source>
        <translation>ᠲᠥᠬᠥᠭᠡᠷᠦᠮᠵᠢ ᠬᠦᠨᠳᠦ ᠨᠡᠷᠡᠶᠢᠳᠦᠨ ᠠᠵᠢᠯᠯᠠᠬᠤ ᠶᠢ ᠳᠡᠮᠵᠢᠬᠦ ᠦᠭᠡᠢ ᠮᠠᠭᠠᠳ ᠂ ᠬᠦᠨᠳᠦ ᠪᠡᠷ ᠨᠡᠷᠡᠶᠢᠳᠦᠯ ᠢᠯᠠᠭᠳᠠᠵᠠᠢ !</translation>
    </message>
</context>
</TS>
